==> smartgwtee-eval-5.0p.zip: com/smartgwt/client/docs/PanelPlacement.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to PanelPlacement.
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickListPlacement
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerExitButton
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerExitButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerClearButton
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerClearButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerNavigationBar
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickListPlacement
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSearchField
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSearchFieldHint
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSearchForm
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerExitButton
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerExitButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSaveButton
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSaveButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerClearButton
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerClearButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerNavigationBar
 */
public interface PanelPlacement {
}

==> smartgwtee-eval-14.0p.zip: com/smartgwt/client/docs/PanelPlacement.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to PanelPlacement.
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickListPlacement
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerExitButton
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerExitButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerClearButton
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerClearButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getPickerNavigationBar
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickListPlacement
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSearchField
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSearchFieldHint
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSearchOrNewValueFieldHint
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSearchForm
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSearchIcon
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerExitButton
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerExitButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSaveButton
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerSaveButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerClearButton
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerClearButtonTitle
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getPickerNavigationBar
 */
public interface PanelPlacement {
}
